**pydaily - Daily python utilities**
============
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/8e2dbb9defe6410793beed44f22783d2)](https://app.codacy.com/app/PingjunChen/pydaily?utm_source=github.com&utm_medium=referral&utm_content=PingjunChen/pydaily&utm_campaign=Badge_Grade_Dashboard)
[![CircleCI](https://circleci.com/gh/PingjunChen/pydaily.svg?style=svg)](https://circleci.com/gh/PingjunChen/pydaily)
[![Documentation Status](https://readthedocs.org/projects/pydaily/badge/?version=latest)](https://pydaily.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/pydaily.svg)](https://badge.fury.io/py/pydaily)
![](https://img.shields.io/github/stars/PingjunChen/pydaily.svg)

Installation
------------
```alpha
pip install pydaily==0.4.0
```

Main modules
------------
#### filesystem-file utilities
#### format-file format utilities
#### log-log utilities
#### tic-time utilities

Documentation
------------
Hosted in [https://pydaily.readthedocs.io](https://pydaily.readthedocs.io), powered by [readthedocs](https://readthedocs.org) and
[Sphinx](http://www.sphinx-doc.org).
